==> textarena-1.1.24.tgz: package/src/interfaces/ArenaNode.ts <==
import { TemplateResult } from 'lit-html';
import ArenaNodeAncestorPart from './node/ArenaNodeAncestorPart';
import ArenaNodeCorePart from './node/ArenaNodeCorePart';
import ArenaNodeScionPart from './node/ArenaNodeScionPart';
import ArenaNodeTextPart from './node/ArenaNodeTextPart';
import {
  ArenaInlineInterface, ArenaMediatorInterface, ArenaRootInterface, ArenaSingleInterface,
} from './Arena';
import { ArenaFormatings } from './ArenaFormating';

export type ArenaNodeRoot = ArenaNodeCorePart<ArenaNodeRoot>
  & ArenaNodeAncestorPart
  & {
  readonly arena: ArenaRootInterface;

  readonly root: true;
  readonly hasParent: false;
};

export type ArenaNodeMediator = ArenaNodeCorePart<ArenaNodeMediator>
  & ArenaNodeScionPart
  & ArenaNodeAncestorPart
  & {
  readonly arena: ArenaMediatorInterface;

  readonly root: false;
  readonly hasParent: true;
};

export type ArenaNodeText = ArenaNodeCorePart<ArenaNodeText>
  & ArenaNodeScionPart
  & ArenaNodeTextPart;

export type ArenaNodeSingle = ArenaNodeCorePart<ArenaNodeSingle>
  & ArenaNodeScionPart
  & {
  readonly arena: ArenaSingleInterface;

  readonly hasChildren: false;
  readonly hasText: false;
  readonly inline: false;
  readonly single: true;
};

export interface ArenaNodeInline {
  readonly arena: ArenaInlineInterface;

  readonly hasParent: false;
  readonly hasChildren: false;
  readonly hasText: false;
  readonly inline: true;
  readonly single: false;

  getHtml(model: ArenaFormatings): TemplateResult | string;

  getOutputHtml(model: ArenaFormatings): string;

  getTags(): [string, string];

  getAttribute(name: string): string | boolean | number;

  setAttribute(name: string, value: string | boolean | number): void;

  clone(): ArenaNodeInline;
}

export type ParentArenaNode = ArenaNodeMediator | ArenaNodeRoot;

export type ChildArenaNode = ArenaNodeMediator
                           | ArenaNodeSingle
                           | ArenaNodeText;

export type AnyArenaNode = ArenaNodeRoot
                         | ChildArenaNode;

==> textarena-1.1.29.tgz: package/src/interfaces/ArenaNode.ts <==
import ArenaNodeAncestorPart from './node/ArenaNodeAncestorPart';
import ArenaNodeCorePart from './node/ArenaNodeCorePart';
import ArenaNodeScionPart from './node/ArenaNodeScionPart';
import ArenaNodeTextPart from './node/ArenaNodeTextPart';
import {
  ArenaInlineInterface, ArenaMediatorInterface, ArenaRootInterface, ArenaSingleInterface,
} from './Arena';
import ArenaAttribute from './ArenaAttribute';

export type ArenaNodeRoot = ArenaNodeCorePart<ArenaNodeRoot>
  & ArenaNodeAncestorPart
  & {
  readonly arena: ArenaRootInterface;

  readonly root: true;
  readonly hasParent: false;
};

export type ArenaNodeMediator = ArenaNodeCorePart<ArenaNodeMediator>
  & ArenaNodeScionPart
  & ArenaNodeAncestorPart
  & {
  readonly arena: ArenaMediatorInterface;

  readonly root: false;
  readonly hasParent: true;
};

export type ArenaNodeText = ArenaNodeCorePart<ArenaNodeText>
  & ArenaNodeScionPart
  & ArenaNodeTextPart;

export type ArenaNodeSingle = ArenaNodeCorePart<ArenaNodeSingle>
  & ArenaNodeScionPart
  & {
  readonly arena: ArenaSingleInterface;

  readonly hasChildren: false;
  readonly hasText: false;
  readonly inline: false;
  readonly single: true;
};

export interface ArenaNodeInline {
  readonly arena: ArenaInlineInterface;

  readonly hasParent: false;
  readonly hasChildren: false;
  readonly hasText: false;
  readonly inline: true;
  readonly single: false;

  // getTemplate(model: ArenaFormatings): TemplateResult | string;

  // getDataHtml(model: ArenaFormatings): string;

  // getOutput(type: string, model: ArenaFormatings): string;

  getTags(): [string, string];

  getAttribute(name: string): ArenaAttribute;

  setAttribute(name: string, value: ArenaAttribute): void;

  clone(): ArenaNodeInline;
}

export type ParentArenaNode = ArenaNodeMediator | ArenaNodeRoot;

export type ChildArenaNode = ArenaNodeMediator
                           | ArenaNodeSingle
                           | ArenaNodeText;

export type AnyArenaNode = ArenaNodeRoot
                         | ChildArenaNode;
